"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LunarClientMod = exports.MiniMapStatus = exports.ServerRuleEnum = exports.NotificationLevel = exports.VoiceChannelUpdateStatus = exports.LunarClientPluginChannel = void 0;
/**
 * Plugin channels Lunar Client uses
 * to establish the connection between
 * the client and the server
 */
var LunarClientPluginChannel;
(function (LunarClientPluginChannel) {
    /**
     * New plugin channel, recommended
     *
     * Value: `lunarclient:pm`
     */
    LunarClientPluginChannel["NEW"] = "lunarclient:pm";
    /**
     * Old plugin channel, shouldn't be
     * used today but the connection seems
     * to be established anyway.
     *
     * Value: `Lunar-Client`
     * @deprecated
     */
    LunarClientPluginChannel["OLD"] = "Lunar-Client";
})(LunarClientPluginChannel = exports.LunarClientPluginChannel || (exports.LunarClientPluginChannel = {}));
/**
 * Status code used by the VoiceChannelUpdatePacket
 */
var VoiceChannelUpdateStatus;
(function (VoiceChannelUpdateStatus) {
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_ADD"] = 0] = "PLAYER_ADD";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_REMOVE"] = 1] = "PLAYER_REMOVE";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_LISTENING"] = 2] = "PLAYER_LISTENING";
    VoiceChannelUpdateStatus[VoiceChannelUpdateStatus["PLAYER_DEAFENED"] = 3] = "PLAYER_DEAFENED";
})(VoiceChannelUpdateStatus = exports.VoiceChannelUpdateStatus || (exports.VoiceChannelUpdateStatus = {}));
/**
 * Different level the notification could be
 */
var NotificationLevel;
(function (NotificationLevel) {
    NotificationLevel["INFO"] = "info";
    NotificationLevel["SUCCESS"] = "success";
    NotificationLevel["WARNING"] = "warning";
    NotificationLevel["ERROR"] = "error";
})(NotificationLevel = exports.NotificationLevel || (exports.NotificationLevel = {}));
/**
 * List of all server rules
 * @see https://github.com/LunarClient/BukkitAPI-NetHandler/blob/master/src/main/java/com/lunarclient/bukkitapi/nethandler/client/obj/ServerRule.java
 */
var ServerRuleEnum;
(function (ServerRuleEnum) {
    /**
     * Whether or not minimap is allowed.
     * Expected value: (String) `NEUTRAL` or `FORCED_OFF`
     */
    ServerRuleEnum["MINIMAP_STATUS"] = "minimapStatus";
    /**
     * Whether or not the server will store waypoints, instead of the client
     */
    ServerRuleEnum["SERVER_HANDLES_WAYPOINTS"] = "serverHandlesWaypoints";
    /**
     * A warning message will be shown when attempting to disconnect if the current
     * game is competitive.
     */
    ServerRuleEnum["COMPETITIVE_GAME"] = "competitiveGame";
    /**
     * If this server forces shaders to be disabled
     */
    ServerRuleEnum["SHADERS_DISABLED"] = "shadersDisabled";
    /**
     * If the server runs legacy enchanting (pre 1.8)
     */
    ServerRuleEnum["LEGACY_ENCHANTING"] = "legacyEnchanting";
    /**
     * If this server has enabled voice chat
     */
    ServerRuleEnum["VOICE_ENABLED"] = "voiceEnabled";
    /**
     * Whether to revert combat mechanics to 1.7
     */
    ServerRuleEnum["LEGACY_COMBAT"] = "legacyCombat";
})(ServerRuleEnum = exports.ServerRuleEnum || (exports.ServerRuleEnum = {}));
/**
 * MinimapStatus values for the server rule
 */
var MiniMapStatus;
(function (MiniMapStatus) {
    MiniMapStatus["NEUTRAL"] = "NEUTRAL";
    MiniMapStatus["FORCED_OFF"] = "FORCED_OFF";
})(MiniMapStatus = exports.MiniMapStatus || (exports.MiniMapStatus = {}));
/**
 * List of all Lunar Client mods
 *
 * Some of them are not present anymore be careful!
 */
var LunarClientMod;
(function (LunarClientMod) {
    LunarClientMod["TIME_CHANGER"] = "time_changer";
    LunarClientMod["NEU"] = "neu";
    LunarClientMod["NAMETAG"] = "nametag";
    LunarClientMod["SHINY_POTS"] = "shinyPots";
    LunarClientMod["BLOCK_OUTLINE"] = "block_outline";
    LunarClientMod["HYPIXEL_MOD"] = "hypixel_mod";
    LunarClientMod["RANGE"] = "range";
    LunarClientMod["REPLAYMOD"] = "replaymod";
    LunarClientMod["RECORDING_INDICATOR"] = "recording_indicator";
    LunarClientMod["PARTICLE_MOD"] = "particleMod";
    LunarClientMod["FOV_MOD"] = "fov_mod";
    LunarClientMod["MOMENTUM_MOD"] = "momentum_mod";
    LunarClientMod["SCREENSHOT"] = "screenshot";
    LunarClientMod["LIGHTING"] = "lighting";
    LunarClientMod["ARMORSTATUS"] = "armorstatus";
    LunarClientMod["ITEM_PHYSIC"] = "itemPhysic";
    LunarClientMod["PACK_ORGANIZER"] = "pack_organizer";
    LunarClientMod["STAFF_XRAY"] = "staff.XRAY";
    LunarClientMod["TITLE_MOD"] = "titleMod";
    LunarClientMod["FPS"] = "fps";
    LunarClientMod["TAB"] = "tab";
    LunarClientMod["COOLDOWNS"] = "cooldowns";
    LunarClientMod["CROSSHAIR"] = "crosshair";
    LunarClientMod["CHAT"] = "chat";
    LunarClientMod["HYPIXEL_BEDWARS"] = "hypixel_bedwars";
    LunarClientMod["COMBO"] = "combo";
    LunarClientMod["SOUND_CHANGER"] = "sound_changer";
    LunarClientMod["SCOREBOARD"] = "scoreboard";
    LunarClientMod["STOPWATCH"] = "stopwatch";
    LunarClientMod["HITBOX"] = "hitbox";
    LunarClientMod["KEYSTROKES"] = "keystrokes";
    LunarClientMod["SATURATION_MOD"] = "saturation_mod";
    LunarClientMod["SATURATION_HUD_MOD"] = "saturation_hud_mod";
    LunarClientMod["HIT_COLOR"] = "hitColor";
    LunarClientMod["SNAPLOOK"] = "snaplook";
    LunarClientMod["MUMBLE_LINK"] = "mumble-link";
    LunarClientMod["BOSSBAR"] = "bossbar";
    LunarClientMod["FREELOOK"] = "freelook";
    LunarClientMod["SCROLLABLE_TOOLTIPS"] = "scrollable_tooltips";
    LunarClientMod["ITEMS2D"] = "items2d";
    LunarClientMod["DAYCOUNTER"] = "daycounter";
    LunarClientMod["SKIN_LAYERS_3D"] = "skinLayers3D";
    LunarClientMod["WEATHER_CHANGER"] = "weather_changer";
    LunarClientMod["CPS"] = "cps";
    LunarClientMod["CLOCK"] = "clock";
    LunarClientMod["TOGGLE_SNEAK"] = "toggleSneak";
    LunarClientMod["MENU_BLUR"] = "menu_blur";
    LunarClientMod["DIRECTIONHUD"] = "directionhud";
    LunarClientMod["TEAMVIEW"] = "teamview";
    LunarClientMod["COORDS"] = "coords";
    LunarClientMod["NICK_HIDER"] = "nickHider";
    LunarClientMod["COLORSATURATION"] = "colorsaturation";
    LunarClientMod["CHUNKBORDERS"] = "chunkborders";
    LunarClientMod["RESOURCE_DISPLAY"] = "resource_display";
    LunarClientMod["SKYBLOCK_ADDONS"] = "skyblockAddons";
    LunarClientMod["QUICKPLAY"] = "quickplay";
    LunarClientMod["TEXT_HOT_KEY"] = "textHotKey";
    LunarClientMod["POTIONEFFECTS"] = "potioneffects";
    LunarClientMod["TNT_COUNTDOWN"] = "tntCountdown";
    LunarClientMod["MOTION_BLUR"] = "motionBlur";
    LunarClientMod["ZOOM"] = "zoom";
    LunarClientMod["WAYPOINTS"] = "waypoints";
    LunarClientMod["PING"] = "ping";
    LunarClientMod["WORLDEDIT_CUI"] = "worldedit_cui";
    LunarClientMod["SERVER_ADDRESS_MOD"] = "serverAddressMod";
    LunarClientMod["MEMORY"] = "memory";
    LunarClientMod["GLINT_COLORIZER"] = "glint_colorizer";
    LunarClientMod["PANORAMA_MAKER"] = "panorama_maker";
    LunarClientMod["ITEM_TRACKER_CHILD"] = "itemTrackerChild";
    LunarClientMod["UHC_OVERLAY"] = "uhc_overlay";
    LunarClientMod["HOLOGRAMS"] = "holograms";
    LunarClientMod["BORDERS"] = "borders";
    LunarClientMod["CUSTOM_NAMEPLATE"] = "custom_nameplate";
    LunarClientMod["COMP_WARN"] = "comp_warn";
    LunarClientMod["VOICE"] = "voice";
    LunarClientMod["TITLES"] = "titles";
})(LunarClientMod = exports.LunarClientMod || (exports.LunarClientMod = {}));
