import { BufWrapper } from '@minecraft-js/bufwrapper';
import * as BufWrapperLunarPlugin from './BufWrapperPlugin';
/** Class representing a packet */
export declare class Packet<T> {
    /** ID of the packet */
    static id: number;
    /** BufWrapper instance that wraps the buffer for this packet */
    buf: BufWrapper<{
        lunar: typeof BufWrapperLunarPlugin;
    }>;
    /** Data associated to this packet */
    data: T;
    /**
     * Read or write a packet
     * @param buf Buffer to create the packet from, can be `undefined` if you are building a packet
     */
    constructor(buf?: BufWrapper<{
        lunar: typeof BufWrapperLunarPlugin;
    }>);
    /**
     * Write the data to the packet
     * @param data Data to write into the packet,
     * if not present it'll use the `data` property.
     * If the `data` parameter is present, it will
     * override the `data` property.
     */
    write(data?: T): void;
    /**
     * Read the packet content
     * @returns The read content of the packet
     */
    read(): T;
}
