import * as protocol from '.';
/**
 * PacketBuiler class, used to easily build packets.
 * @example
 * ```javascript
 * const { packet } = new PacketBuilder('CooldownPacket', {
 *   id: 'pearl',
 *   durationMs: 5000,
 *   iconId: 368
 * });
 *
 * // Do something with `packet`
 * ```
 */
export default class LunarClientPacketBuilder<T extends keyof typeof protocol> {
    packet: InstanceType<typeof protocol[T]>;
    /**
     * PacketBuiler class, used to easily build packets.
     * @param packet Name of the packet to build
     * @param data Data of the packet
     * @example
     * ```javascript
     * const { packet } = new PacketBuilder('CooldownPacket', {
     *   id: 'pearl',
     *   durationMs: 5000,
     *   iconId: 368
     * });
     *
     * // Do something with `packet`
     * ```
     */
    constructor(packet: T, data: InstanceType<typeof protocol[T]>['data']);
}
