"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bufwrapper_1 = require("@minecraft-js/bufwrapper");
const protocol = require(".");
const BufWrapperLunarPlugin = require("./BufWrapperPlugin");
/**
 * PacketBuiler class, used to easily build packets.
 * @example
 * ```javascript
 * const { packet } = new PacketBuilder('CooldownPacket', {
 *   id: 'pearl',
 *   durationMs: 5000,
 *   iconId: 368
 * });
 *
 * // Do something with `packet`
 * ```
 */
class LunarClientPacketBuilder {
    /**
     * PacketBuiler class, used to easily build packets.
     * @param packet Name of the packet to build
     * @param data Data of the packet
     * @example
     * ```javascript
     * const { packet } = new PacketBuilder('CooldownPacket', {
     *   id: 'pearl',
     *   durationMs: 5000,
     *   iconId: 368
     * });
     *
     * // Do something with `packet`
     * ```
     */
    constructor(packet, data) {
        const Packet = protocol[packet];
        const buf = new bufwrapper_1.BufWrapper(null, {
            oneConcat: true,
            plugins: { lunar: BufWrapperLunarPlugin },
        });
        buf.writeVarInt(Packet.id);
        this.packet = new Packet(buf);
        // @ts-ignore TODO: type this so it's not weird
        this.packet.write(data);
    }
}
exports.default = LunarClientPacketBuilder;
