"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bufwrapper_1 = require("@minecraft-js/bufwrapper");
const node_events_1 = require("node:events");
const protocol = require(".");
const BufWrapperLunarPlugin = require("./BufWrapperPlugin");
const events = Object.keys(protocol);
const packets = Object.values(protocol);
/**
 * Instantiate a new PacketHandler class.
 * This class extends EventEmitter and for
 * each successfuly handled packet the event
 * emitter will emit an event. If a `CooldownPacket`
 * is received, an event with name `CooldownPacket`
 * is emitted.
 *
 * @example
 * ```javascript
 * const packetHandler = new PacketHandler();
 *
 * // Call PacketHandler#handle with
 * // the buffer everytime you receive
 * // a packet
 *
 * packetHandler.on('CooldownPacket', ({ data }) => {
 *   // Do something with data
 * });
 * ```
 */
class LunarClientPacketHandler extends node_events_1.EventEmitter {
    /**
     * Handle a packet, if everything is successful
     * an event will be emited with the content of
     * the packet
     */
    handle(buffer) {
        const buf = new bufwrapper_1.BufWrapper(buffer, {
            plugins: { lunar: BufWrapperLunarPlugin },
        });
        const id = buf.readVarInt();
        const Packet = packets.find((p) => p.id === id);
        if (!Packet)
            throw new Error(`Unknown packet (id=${id})`);
        const packet = new Packet(buf);
        packet.read();
        const event = events.find((key) => packet[key] === Packet);
        // @ts-ignore
        this.emit(event, packet);
    }
}
exports.default = LunarClientPacketHandler;
